package com.srs.teacher.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.srs.teacher.domain.SysTeacherKpiFillingBonusPointsMaterials;
import org.apache.ibatis.annotations.Param;

/**
 * 业绩考核-个人填报-加分项佐证材料Mapper接口
 *
 * @author Codex
 * @date 2026-03-26
 */
public interface SysTeacherKpiFillingBonusPointsMaterialsMapper extends BaseMapper<SysTeacherKpiFillingBonusPointsMaterials> {
    SysTeacherKpiFillingBonusPointsMaterials selectSysTeacherKpiFillingBonusPointsMaterialsById(Long id);

    List<SysTeacherKpiFillingBonusPointsMaterials> selectSysTeacherKpiFillingBonusPointsMaterialsList(SysTeacherKpiFillingBonusPointsMaterials materials);

    List<SysTeacherKpiFillingBonusPointsMaterials> selectSysTeacherKpiFillingBonusPointsMaterialsByFdyName(
            @Param("fdyName") String fdyName,
            @Param("fillingYear") String fillingYear,
            @Param("fillingMonth") String fillingMonth,
            @Param("classType") String classType,
            @Param("bonusType") String bonusType);

    int insertSysTeacherKpiFillingBonusPointsMaterials(SysTeacherKpiFillingBonusPointsMaterials materials);

    int updateSysTeacherKpiFillingBonusPointsMaterials(SysTeacherKpiFillingBonusPointsMaterials materials);

    int deleteSysTeacherKpiFillingBonusPointsMaterialsById(Long id);

    int deleteSysTeacherKpiFillingBonusPointsMaterialsByIds(Long[] ids);
}
